svn commit: trunk/busybox: applets docs

aldot at busybox.net aldot at busybox.net
Thu Mar 23 16:53:00 UTC 2006


Author: aldot
Date: 2006-03-23 08:52:59 -0800 (Thu, 23 Mar 2006)
New Revision: 14629

Log:
- correct typo


Modified:
   trunk/busybox/applets/applets.c
   trunk/busybox/docs/contributing.txt


Changeset:
Modified: trunk/busybox/applets/applets.c
===================================================================
--- trunk/busybox/docs/contributing.txt	2006-03-23 16:49:22 UTC (rev 14628)
+++ trunk/busybox/docs/contributing.txt	2006-03-23 16:52:59 UTC (rev 14629)
@@ -400,7 +400,7 @@
 changes directly to CVS. This is nice because you don't have to wait for
 someone else to commit your change for you, you can just do it yourself.
 
-But note that this is a priviledge that comes with some responsibilities. You
+But note that this is a privilege that comes with some responsibilities. You
 should test your changes before you commit them. You should also talk to an
 applet maintainer before you make any kind of sweeping changes to somebody
 else's code. Big changes should still go to the mailing list first. Remember,




More information about the busybox-cvs mailing list
--- trunk/busybox/applets/applets.c	2006-03-23 16:49:22 UTC (rev 14628)
+++ trunk/busybox/applets/applets.c	2006-03-23 16:52:59 UTC (rev 14629)
@@ -372,7 +372,7 @@
 	  } else
 		setuid (ruid);                  /* no suid -> drop */
 	} else {
 		/* default: drop all priviledges */
 	  setgid (rgid);
 	  setuid (ruid);
 	}
@@ -391,9 +391,9 @@
 
   if (applet->need_suid == _BB_SUID_ALWAYS) {
 	if (geteuid () != 0)
-	  bb_error_msg_and_die ("This applet requires root priviledges!");
+	  bb_error_msg_and_die ("This applet requires root privileges!");
   } else if (applet->need_suid == _BB_SUID_NEVER) {
-	setgid (rgid);                          /* drop all priviledges */
+	setgid (rgid);                          /* drop all privileges */
 	setuid (ruid);
   }
 }
@@ -372,7 +372,7 @@
 		setuid (ruid);                  /* no suid -> drop */
 	} else {
-		/* default: drop all priviledges */
+		/* default: drop all privileges */
 	  setgid (rgid);
 	  setuid (ruid);

Modified: trunk/busybox/docs/contributing.txt
===================================================================